==> api-1.0.36-sources.jar: io/envoyproxy/envoy/service/endpoint/v3/LocalityEndpointDiscoveryServiceGrpc.java <==
package io.envoyproxy.envoy.service.endpoint.v3;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.48.1)",
    comments = "Source: envoy/service/endpoint/v3/leds.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class LocalityEndpointDiscoveryServiceGrpc {

  private LocalityEndpointDiscoveryServiceGrpc() {}

  public static final String SERVICE_NAME = "envoy.service.endpoint.v3.LocalityEndpointDiscoveryService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest,
      io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> getDeltaLocalityEndpointsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "DeltaLocalityEndpoints",
      requestType = io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest.class,
      responseType = io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static io.grpc.MethodDescriptor<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest,
      io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> getDeltaLocalityEndpointsMethod() {
    io.grpc.MethodDescriptor<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest, io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> getDeltaLocalityEndpointsMethod;
    if ((getDeltaLocalityEndpointsMethod = LocalityEndpointDiscoveryServiceGrpc.getDeltaLocalityEndpointsMethod) == null) {
      synchronized (LocalityEndpointDiscoveryServiceGrpc.class) {
        if ((getDeltaLocalityEndpointsMethod = LocalityEndpointDiscoveryServiceGrpc.getDeltaLocalityEndpointsMethod) == null) {
          LocalityEndpointDiscoveryServiceGrpc.getDeltaLocalityEndpointsMethod = getDeltaLocalityEndpointsMethod =
              io.grpc.MethodDescriptor.<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest, io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "DeltaLocalityEndpoints"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse.getDefaultInstance()))
              .setSchemaDescriptor(new LocalityEndpointDiscoveryServiceMethodDescriptorSupplier("DeltaLocalityEndpoints"))
              .build();
        }
      }
    }
    return getDeltaLocalityEndpointsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static LocalityEndpointDiscoveryServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceStub>() {
        @java.lang.Override
        public LocalityEndpointDiscoveryServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LocalityEndpointDiscoveryServiceStub(channel, callOptions);
        }
      };
    return LocalityEndpointDiscoveryServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static LocalityEndpointDiscoveryServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceBlockingStub>() {
        @java.lang.Override
        public LocalityEndpointDiscoveryServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LocalityEndpointDiscoveryServiceBlockingStub(channel, callOptions);
        }
      };
    return LocalityEndpointDiscoveryServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static LocalityEndpointDiscoveryServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceFutureStub>() {
        @java.lang.Override
        public LocalityEndpointDiscoveryServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LocalityEndpointDiscoveryServiceFutureStub(channel, callOptions);
        }
      };
    return LocalityEndpointDiscoveryServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class LocalityEndpointDiscoveryServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * The resource_names_subscribe resource_names_unsubscribe fields in DeltaDiscoveryRequest
     * specify a list of glob collections to subscribe to updates for.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest> deltaLocalityEndpoints(
        io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> responseObserver) {
      return io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getDeltaLocalityEndpointsMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getDeltaLocalityEndpointsMethod(),
            io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
              new MethodHandlers<
                io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest,
                io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse>(
                  this, METHODID_DELTA_LOCALITY_ENDPOINTS)))
          .build();
    }
  }

  /**
   */
  public static final class LocalityEndpointDiscoveryServiceStub extends io.grpc.stub.AbstractAsyncStub<LocalityEndpointDiscoveryServiceStub> {
    private LocalityEndpointDiscoveryServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LocalityEndpointDiscoveryServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LocalityEndpointDiscoveryServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * The resource_names_subscribe resource_names_unsubscribe fields in DeltaDiscoveryRequest
     * specify a list of glob collections to subscribe to updates for.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest> deltaLocalityEndpoints(
        io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> responseObserver) {
      return io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getDeltaLocalityEndpointsMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class LocalityEndpointDiscoveryServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<LocalityEndpointDiscoveryServiceBlockingStub> {
    private LocalityEndpointDiscoveryServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LocalityEndpointDiscoveryServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LocalityEndpointDiscoveryServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class LocalityEndpointDiscoveryServiceFutureStub extends io.grpc.stub.AbstractFutureStub<LocalityEndpointDiscoveryServiceFutureStub> {
    private LocalityEndpointDiscoveryServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LocalityEndpointDiscoveryServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LocalityEndpointDiscoveryServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_DELTA_LOCALITY_ENDPOINTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final LocalityEndpointDiscoveryServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(LocalityEndpointDiscoveryServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_DELTA_LOCALITY_ENDPOINTS:
          return (io.grpc.stub.StreamObserver<Req>) serviceImpl.deltaLocalityEndpoints(
              (io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class LocalityEndpointDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    LocalityEndpointDiscoveryServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.envoyproxy.envoy.service.endpoint.v3.LedsProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("LocalityEndpointDiscoveryService");
    }
  }

  private static final class LocalityEndpointDiscoveryServiceFileDescriptorSupplier
      extends LocalityEndpointDiscoveryServiceBaseDescriptorSupplier {
    LocalityEndpointDiscoveryServiceFileDescriptorSupplier() {}
  }

  private static final class LocalityEndpointDiscoveryServiceMethodDescriptorSupplier
      extends LocalityEndpointDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    LocalityEndpointDiscoveryServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (LocalityEndpointDiscoveryServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new LocalityEndpointDiscoveryServiceFileDescriptorSupplier())
              .addMethod(getDeltaLocalityEndpointsMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> api-1.0.44-sources.jar: io/envoyproxy/envoy/service/endpoint/v3/LocalityEndpointDiscoveryServiceGrpc.java <==
package io.envoyproxy.envoy.service.endpoint.v3;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.62.2)",
    comments = "Source: envoy/service/endpoint/v3/leds.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class LocalityEndpointDiscoveryServiceGrpc {

  private LocalityEndpointDiscoveryServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "envoy.service.endpoint.v3.LocalityEndpointDiscoveryService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest,
      io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> getDeltaLocalityEndpointsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "DeltaLocalityEndpoints",
      requestType = io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest.class,
      responseType = io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static io.grpc.MethodDescriptor<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest,
      io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> getDeltaLocalityEndpointsMethod() {
    io.grpc.MethodDescriptor<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest, io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> getDeltaLocalityEndpointsMethod;
    if ((getDeltaLocalityEndpointsMethod = LocalityEndpointDiscoveryServiceGrpc.getDeltaLocalityEndpointsMethod) == null) {
      synchronized (LocalityEndpointDiscoveryServiceGrpc.class) {
        if ((getDeltaLocalityEndpointsMethod = LocalityEndpointDiscoveryServiceGrpc.getDeltaLocalityEndpointsMethod) == null) {
          LocalityEndpointDiscoveryServiceGrpc.getDeltaLocalityEndpointsMethod = getDeltaLocalityEndpointsMethod =
              io.grpc.MethodDescriptor.<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest, io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "DeltaLocalityEndpoints"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse.getDefaultInstance()))
              .setSchemaDescriptor(new LocalityEndpointDiscoveryServiceMethodDescriptorSupplier("DeltaLocalityEndpoints"))
              .build();
        }
      }
    }
    return getDeltaLocalityEndpointsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static LocalityEndpointDiscoveryServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceStub>() {
        @java.lang.Override
        public LocalityEndpointDiscoveryServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LocalityEndpointDiscoveryServiceStub(channel, callOptions);
        }
      };
    return LocalityEndpointDiscoveryServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static LocalityEndpointDiscoveryServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceBlockingStub>() {
        @java.lang.Override
        public LocalityEndpointDiscoveryServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LocalityEndpointDiscoveryServiceBlockingStub(channel, callOptions);
        }
      };
    return LocalityEndpointDiscoveryServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static LocalityEndpointDiscoveryServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LocalityEndpointDiscoveryServiceFutureStub>() {
        @java.lang.Override
        public LocalityEndpointDiscoveryServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LocalityEndpointDiscoveryServiceFutureStub(channel, callOptions);
        }
      };
    return LocalityEndpointDiscoveryServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     * <pre>
     * The resource_names_subscribe resource_names_unsubscribe fields in DeltaDiscoveryRequest
     * specify a list of glob collections to subscribe to updates for.
     * </pre>
     */
    default io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest> deltaLocalityEndpoints(
        io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> responseObserver) {
      return io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getDeltaLocalityEndpointsMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service LocalityEndpointDiscoveryService.
   */
  public static abstract class LocalityEndpointDiscoveryServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return LocalityEndpointDiscoveryServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service LocalityEndpointDiscoveryService.
   */
  public static final class LocalityEndpointDiscoveryServiceStub
      extends io.grpc.stub.AbstractAsyncStub<LocalityEndpointDiscoveryServiceStub> {
    private LocalityEndpointDiscoveryServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LocalityEndpointDiscoveryServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LocalityEndpointDiscoveryServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * The resource_names_subscribe resource_names_unsubscribe fields in DeltaDiscoveryRequest
     * specify a list of glob collections to subscribe to updates for.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest> deltaLocalityEndpoints(
        io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse> responseObserver) {
      return io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getDeltaLocalityEndpointsMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service LocalityEndpointDiscoveryService.
   */
  public static final class LocalityEndpointDiscoveryServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<LocalityEndpointDiscoveryServiceBlockingStub> {
    private LocalityEndpointDiscoveryServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LocalityEndpointDiscoveryServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LocalityEndpointDiscoveryServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service LocalityEndpointDiscoveryService.
   */
  public static final class LocalityEndpointDiscoveryServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<LocalityEndpointDiscoveryServiceFutureStub> {
    private LocalityEndpointDiscoveryServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LocalityEndpointDiscoveryServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LocalityEndpointDiscoveryServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_DELTA_LOCALITY_ENDPOINTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_DELTA_LOCALITY_ENDPOINTS:
          return (io.grpc.stub.StreamObserver<Req>) serviceImpl.deltaLocalityEndpoints(
              (io.grpc.stub.StreamObserver<io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getDeltaLocalityEndpointsMethod(),
          io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
            new MethodHandlers<
              io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryRequest,
              io.envoyproxy.envoy.service.discovery.v3.DeltaDiscoveryResponse>(
                service, METHODID_DELTA_LOCALITY_ENDPOINTS)))
        .build();
  }

  private static abstract class LocalityEndpointDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    LocalityEndpointDiscoveryServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.envoyproxy.envoy.service.endpoint.v3.LedsProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("LocalityEndpointDiscoveryService");
    }
  }

  private static final class LocalityEndpointDiscoveryServiceFileDescriptorSupplier
      extends LocalityEndpointDiscoveryServiceBaseDescriptorSupplier {
    LocalityEndpointDiscoveryServiceFileDescriptorSupplier() {}
  }

  private static final class LocalityEndpointDiscoveryServiceMethodDescriptorSupplier
      extends LocalityEndpointDiscoveryServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    LocalityEndpointDiscoveryServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (LocalityEndpointDiscoveryServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new LocalityEndpointDiscoveryServiceFileDescriptorSupplier())
              .addMethod(getDeltaLocalityEndpointsMethod())
              .build();
        }
      }
    }
    return result;
  }
}
